from distutils.core import setup

setup(
       name = 'teddy1995',
       version = '1.0.0',
       py_modules = ['nester'],
       author = 'teddy',
       author_email = '530128985@qq.com',
       url = '',
       description = 'a printer of nested lists',
       )
